@@ -1,4 +1,8 @@
-pub type EtwinError = Box<dyn ::std::error::Error + Send + Sync + 'static>;
+pub type AnyError = Box<dyn ::std::error::Error + Send + Sync + 'static>;
+
+pub fn to_any_error<E: ::std::error::Error + Send + Sync + 'static>(e: E) -> AnyError {
+  Box::new(e)
+}
 
 #[macro_export]
 macro_rules! declare_decimal_id {
@@ -34,6 +38,15 @@ macro_rules! declare_decimal_id {
         f(buf.format(self.0))
       }
 
+      /// Constructs a id with checks.
+      $struct_vis fn new(id: $struct_ty) -> ::std::result::Result<Self, $err_name> {
+        if $bounds.contains(&id) {
+          Ok(Self(id))
+        } else {
+          Err($err_name(()))
+        }
+      }
+
       /// Constructs a id without checking bounds
       ///
       /// # Safety
@@ -53,7 +66,7 @@ macro_rules! declare_decimal_id {
     impl ::std::str::FromStr for $struct_name {
       type Err = $err_name;
 
-      fn from_str(s: &str) ->  ::std::result::Result<Self, Self::Err> {
+      fn from_str(s: &str) -> ::std::result::Result<Self, Self::Err> {
         match s.parse::<$struct_ty>() {
           Ok(id) if $bounds.contains(&id) => Ok(Self(id)),
           _ => Err($err_name(()))
@@ -479,6 +492,14 @@ macro_rules! declare_new_uuid {
       $struct_vis const fn from_uuid(inner: ::uuid::Uuid) -> Self {
         Self(inner)
       }
+
+      $struct_vis const fn into_uuid(self) -> ::uuid::Uuid {
+        self.0
+      }
+
+      $struct_vis fn to_hex(&self) -> String {
+        self.0.to_simple().to_string()
+      }
     }
 
     impl ::std::fmt::Display for $struct_name {
